<?php

class BILLINGFREEKASSA_CTRL_Admin extends ADMIN_CTRL_Abstract
{

    public function index()
    {
        $billingService = BOL_BillingService::getInstance();
        $language = OW::getLanguage();

        $freekassaConfigForm = new FreekassaConfigForm();
        $this->addForm($freekassaConfigForm);

        if ( OW::getRequest()->isPost() && $freekassaConfigForm->isValid($_POST) )
        {
            $res = $freekassaConfigForm->process();
            OW::getFeedback()->info($language->text('billingfreekassa', 'settings_updated'));
            $this->redirect();
        }

        $adapter = new BILLINGFREEKASSA_CLASS_FreekassaAdapter();
        $this->assign('logoUrl', $adapter->getLogoUrl());

        $gateway = $billingService->findGatewayByKey(BILLINGFREEKASSA_CLASS_FreekassaAdapter::GATEWAY_KEY);
        $this->assign('gateway', $gateway);

        $this->assign('activeCurrency', $billingService->getActiveCurrency());

        $supported = $billingService->currencyIsSupported($gateway->currencies);
        $this->assign('currSupported', $supported);

        $this->setPageHeading(OW::getLanguage()->text('billingfreekassa', 'config_page_heading'));
        $this->setPageHeadingIconClass('ow_ic_app');
    }
}

class FreekassaConfigForm extends Form
{

    public function __construct()
    {
        parent::__construct('freekassa-config-form');

        $language = OW::getLanguage();
        $billingService = BOL_BillingService::getInstance();
        $gwKey = BILLINGFREEKASSA_CLASS_FreekassaAdapter::GATEWAY_KEY;

        $element = new TextField('fkSecretWord_1');
        $element->setValue($billingService->getGatewayConfigValue($gwKey, 'fkSecretWord_1'));
        $this->addElement($element);
        
        $element = new TextField('fkSecretWord_2');
        $element->setValue($billingService->getGatewayConfigValue($gwKey, 'fkSecretWord_2'));
        $this->addElement($element);

        $element = new TextField('fkMerchantId');
        $element->setValue($billingService->getGatewayConfigValue($gwKey, 'fkMerchantId'));
        $this->addElement($element);
        
        $element = new Selectbox('fkCurrency');
        $element
            ->setValue($billingService->getGatewayConfigValue($gwKey, 'fkCurrency'))
            ->setHasInvitation(false)
            ->addOption('rur', 'RUB')
            ->addOption('usd', 'USD')
            ->addOption('eur', 'EUR');
        $this->addElement($element);
        
        $element = new Selectbox('lang');
        $element
            ->setValue($billingService->getGatewayConfigValue($gwKey, 'lang'))
            ->setHasInvitation(false)
            ->addOption('ru', 'Русский');
        $this->addElement($element);
        
        $element = new Selectbox('tabNum');
        $element
            ->setValue($billingService->getGatewayConfigValue($gwKey, 'tabNum'))
            ->setHasInvitation(false)
            ->addOption('1', 'Electronic Systems')
            ->addOption('2', 'Cash / Bank Transfers')
            ->addOption('3', 'Terminals')
            ->addOption('4', 'SMS payments');
        $this->addElement($element);

        // submit
        $submit = new Submit('save');
        $submit->setValue($language->text('billingfreekassa', 'btn_save'));
        $this->addElement($submit);
    }

    public function process()
    {
        $values = $this->getValues();

        $billingService = BOL_BillingService::getInstance();
        $gwKey = BILLINGFREEKASSA_CLASS_FreekassaAdapter::GATEWAY_KEY;

        $billingService->setGatewayConfigValue($gwKey, 'fkSecretWord_1', $values['fkSecretWord_1']);
        $billingService->setGatewayConfigValue($gwKey, 'fkSecretWord_2', $values['fkSecretWord_2']);
        $billingService->setGatewayConfigValue($gwKey, 'fkMerchantId', $values['fkMerchantId']);
        $billingService->setGatewayConfigValue($gwKey, 'fkCurrency', $values['fkCurrency']);
        $billingService->setGatewayConfigValue($gwKey, 'lang', $values['lang']);
        $billingService->setGatewayConfigValue($gwKey, 'tabNum', $values['tabNum']);
    }
}
